@@ -4,7 +4,7 @@ namespace LAM\HEADER;
 $Id$
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2016  Roland Gruber
+  Copyright (C) 2003 - 2017  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -86,7 +86,8 @@ $toolSettings = $_SESSION['config']->getToolSettings();
 // sort tools
 $toSort = array();
 for ($i = 0; $i < sizeof($availableTools); $i++) {
-	$myTool = new $availableTools[$i]();
+	$toolClass = $availableTools[$i];
+    $myTool = new $toolClass();
 	if ($myTool->getRequiresWriteAccess() && !checkIfWriteAccessIsAllowed()) {
 		continue;
 	}
@@ -98,7 +99,8 @@ for ($i = 0; $i < sizeof($availableTools); $i++) {
 		continue;
 	}
 	// check if hidden by config
-	if (isset($toolSettings['tool_hide_' . get_class($myTool)]) && ($toolSettings['tool_hide_' . get_class($myTool)] == 'true')) {
+	$toolName = substr($toolClass, strrpos($toolClass, '\\') + 1);
+	if (isset($toolSettings['tool_hide_' . $toolName]) && ($toolSettings['tool_hide_' . $toolName] == 'true')) {
 		continue;
 	}
 	$toSort[$availableTools[$i]] = $myTool->getPosition();
@@ -208,14 +210,13 @@ jQuery(document).ready(function() {
 function printTypeTabs($headerPrefix) {
 	$typeManager = new \LAM\TYPES\TypeManager();
 	$types = $typeManager->getConfiguredTypes();
-	$linkList = array();
 	foreach ($types as $type) {
 		if ($type->isHidden()) {
 			continue;
 		}
 		$link = '<a href="' . $headerPrefix . 'lists/list.php?type=' . $type->getId() .
 		'" onmouseover="jQuery(this).addClass(\'tabs-hover\');" onmouseout="jQuery(this).removeClass(\'tabs-hover\');">' .
-		'<img height="16" width="16" alt="' . $type->getId() . '" src="' . $headerPrefix . '../graphics/' . $type->getScope() . '.png">&nbsp;' .
+		'<img height="16" width="16" alt="' . $type->getId() . '" src="' . $headerPrefix . '../graphics/' . $type->getIcon() . '">&nbsp;' .
 		$type->getAlias() . '</a>';
 		echo '<li id="tab_' . $type->getId() . '" class="ui-state-default ui-corner-top">';
 		echo $link;
