@@ -75,7 +75,6 @@ setlanguage();
 // Unset PDF structure definitions in session if set
 if(isset($_SESSION['currentPDFStructure'])) {
 	unset($_SESSION['currentPDFStructure']);
-	unset($_SESSION['currentPageDefinitions']);
 }
 
 // check if user is logged in, if not go to login
@@ -105,14 +104,15 @@ $container = new htmlTable();
 $container->addElement(new htmlTitle(_('PDF editor')), true);
 
 if (isset($_POST['deleteProfile']) && ($_POST['deleteProfile'] == 'true')) {
+	$typeToDelete = $typeManager->getConfiguredType($_POST['profileDeleteType']);
 	// delete structure
 	if (\LAM\PDF\deletePDFStructure($_POST['profileDeleteType'], $_POST['profileDeleteName'])) {
-		$message = new htmlStatusMessage('INFO', _('Deleted PDF structure.'), \LAM\TYPES\getTypeAlias($_POST['profileDeleteType']) . ': ' . htmlspecialchars($_POST['profileDeleteName']));
+		$message = new htmlStatusMessage('INFO', _('Deleted PDF structure.'), $typeToDelete->getAlias() . ': ' . htmlspecialchars($_POST['profileDeleteName']));
 		$message->colspan = 10;
 		$container->addElement($message, true);
 	}
 	else {
-		$message = new htmlStatusMessage('ERROR', _('Unable to delete PDF structure!'), \LAM\TYPES\getTypeAlias($_POST['profileDeleteType']) . ': ' . htmlspecialchars($_POST['profileDeleteName']));
+		$message = new htmlStatusMessage('ERROR', _('Unable to delete PDF structure!'), $typeToDelete->getAlias() . ': ' . htmlspecialchars($_POST['profileDeleteName']));
 		$message->colspan = 10;
 		$container->addElement($message, true);
 	}
@@ -194,6 +194,7 @@ foreach ($sortedTypes as $typeId => $title) {
 		'typeId' => $type->getId(),
 		'scope' => $type->getScope(),
 		'title' => $title,
+		'icon' => $type->getIcon(),
 		'templates' => "");
 	$availableTypes[$title] = $type->getId();
 }
@@ -222,6 +223,12 @@ include '../main_header.php';
 			$container->addElement($message, true);
 		}
 
+		if (isset($_GET['loadFailed'])) {
+			$message = new htmlStatusMessage("ERROR", _("Unable to read PDF structure."), htmlspecialchars($_GET['name']));
+			$message->colspan = 10;
+			$container->addElement($message, true);
+		}
+
 		// new template
 		if (!empty($availableTypes)) {
 			$container->addElement(new htmlSubTitle(_('Create a new PDF structure')), true);
@@ -244,7 +251,7 @@ include '../main_header.php';
 				$existingContainer->addElement(new htmlSpacer(null, '10px'), true);
 			}
 
-			$existingContainer->addElement(new htmlImage('../../graphics/' . $templateClasses[$i]['scope'] . '.png'));
+			$existingContainer->addElement(new htmlImage('../../graphics/' . $templateClasses[$i]['icon']));
 			$existingContainer->addElement(new htmlSpacer('3px', null));
 			$existingContainer->addElement(new htmlOutputText($templateClasses[$i]['title']));
 			$existingContainer->addElement(new htmlSpacer('3px', null));
